/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.gtk.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef GSD_XSETTINGS_MANAGER_ADAPTOR_H
#define GSD_XSETTINGS_MANAGER_ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "gsd-xsettings-manager/gsd-xsettings-manager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.gtk.Settings
 */
class GSDXSettingsManagerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.gtk.Settings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.gtk.Settings\">\n"
"    <property access=\"read\" type=\"x\" name=\"FontconfigTimestamp\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"Modules\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"EnableAnimations\"/>\n"
"  </interface>\n"
        "")
public:
    GSDXSettingsManagerAdaptor(GSDXSettingsManager *parent);
    ~GSDXSettingsManagerAdaptor() override;

    inline GSDXSettingsManager *parent() const
    { return static_cast<GSDXSettingsManager *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool EnableAnimations READ enableAnimations)
    bool enableAnimations() const;

    Q_PROPERTY(qlonglong FontconfigTimestamp READ fontconfigTimestamp)
    qlonglong fontconfigTimestamp() const;

    Q_PROPERTY(QString Modules READ modules)
    QString modules() const;

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
};

#endif
