/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.gtk.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "gsd_xsettings_manager_adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class GSDXSettingsManagerAdaptor
 */

GSDXSettingsManagerAdaptor::GSDXSettingsManagerAdaptor(GSDXSettingsManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

GSDXSettingsManagerAdaptor::~GSDXSettingsManagerAdaptor()
{
    // destructor
}

bool GSDXSettingsManagerAdaptor::enableAnimations() const
{
    // get the value of property EnableAnimations
    return qvariant_cast< bool >(parent()->property("EnableAnimations"));
}

qlonglong GSDXSettingsManagerAdaptor::fontconfigTimestamp() const
{
    // get the value of property FontconfigTimestamp
    return qvariant_cast< qlonglong >(parent()->property("FontconfigTimestamp"));
}

QString GSDXSettingsManagerAdaptor::modules() const
{
    // get the value of property Modules
    return qvariant_cast< QString >(parent()->property("Modules"));
}


#include "moc_gsd_xsettings_manager_adaptor.cpp"
